@@ -19,6 +19,7 @@ BSgenome_datapkgs <- c(
   "BSgenome.Celegans.UCSC.ce2",
   "BSgenome.Celegans.UCSC.ce6",
   "BSgenome.Celegans.UCSC.ce10",
+  "BSgenome.Celegans.UCSC.ce11",
   "BSgenome.Cfamiliaris.UCSC.canFam2",
   "BSgenome.Cfamiliaris.UCSC.canFam3",
   "BSgenome.Dmelanogaster.UCSC.dm2",
@@ -27,6 +28,7 @@ BSgenome_datapkgs <- c(
   "BSgenome.Drerio.UCSC.danRer5",
   "BSgenome.Drerio.UCSC.danRer6",
   "BSgenome.Drerio.UCSC.danRer7",
+  "BSgenome.Drerio.UCSC.danRer10",
   "BSgenome.Ecoli.NCBI.20080805",
   "BSgenome.Gaculeatus.UCSC.gasAcu1",
   "BSgenome.Ggallus.UCSC.galGal3",
@@ -52,7 +54,8 @@ BSgenome_datapkgs <- c(
   "BSgenome.Scerevisiae.UCSC.sacCer2",
   "BSgenome.Scerevisiae.UCSC.sacCer3",
   "BSgenome.Sscrofa.UCSC.susScr3",
-  "BSgenome.Tguttata.UCSC.taeGut1"
+  "BSgenome.Tguttata.UCSC.taeGut1",
+  "BSgenome.Tguttata.UCSC.taeGut2"
 )
 
 for (pkg in BSgenome_datapkgs) {
